# Table of Contents

- [sso-configuration-process](<./sso-configuration-process.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SSO Configuration Process](<./SSO-Configuration-Process.md>)
  - [Before You Start](<./SSO-Configuration-Process/Before-You-Start.md>)
  - [Step 1: Starting SSO Authentication Setup](<./SSO-Configuration-Process/Step-1-Starting-SSO-Authentication-Setup.md>)
  - [Step 2: Add a New Identity Provider](<./SSO-Configuration-Process/Step-2-Add-a-New-Identity-Provider.md>)
  - [Step 3: Test the Identity Provider Configuration](<./SSO-Configuration-Process/Step-3-Test-the-Identity-Provider-Configuration.md>)
  - [Step 4: Activate an Identity Provider](<./SSO-Configuration-Process/Step-4-Activate-an-Identity-Provider.md>)
  - [FAQ](<./SSO-Configuration-Process/FAQ.md>)
